==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/TCL/tkvsetupvoice.tcl <==
# tkvsetupvoice.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvpaths
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Setup VOICE"
wm iconname $w "tkVoice Setup VOICE"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global drawvoice

proc restartmsg {} {
global w
tk_messageBox -icon warning -type ok \
	-title "VOICE SUPPORT WARNING" -parent $w\
	-message "\"RESTART\" of tkVoice is required for VOICE support changes to take affect.\n\nRemember to \"SAVE\"."
}

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicevoice}
image create photo tkvoicevoice -file [file join $tkvoicedir/image/tkvoicevoice.gif]

label $w.gif.tkvoicevoice -image tkvoicevoice -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicevoice -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right


#########################

frame $w.top
pack $w.top -side top -expand yes -pady .3c -padx .5c
checkbutton $w.top.drawvoice -text "VOICE support ON/OFF" -variable drawvoice \
            -relief flat -onvalue "1" -offvalue "0" -command "restartmsg"
pack $w.top.drawvoice -side top -pady 2 -anchor w

label $w.msg1 -font $font -wraplength 4i -justify left -text "\t\"tkvoice\" installation directory ?\n\tDefault is \"/usr/local/tkvoice\"\t"
label $w.msg2 -font $font -wraplength 4i -justify left -text "\n\t\"vgetty\" spool directory ?\n\tDefault is \"/var/spool/voice\"\t\t"
label $w.msg3 -font $font -wraplength 4i -justify left -text "\n\t\"incoming\" directory ?\n(with respect to $voicedir)\n\tDefault is \"/incoming\"\t\t"
label $w.msg4 -font $font -wraplength 4i -justify left -text "\n\t\"messages\" directory ?\n(with respect to $voicedir)\n\tDefault is \"/messages\"\t\t"
label $w.msg5 -font $font -wraplength 4i -justify left -text "\n\tYour outgoing message?\n(with respect to $voicedir$voiceout)\n\tDefault is \"greeting\"\t\t"

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savevoice; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -side left -expand 1

foreach i "tkvoicedir voicedir voicein voiceout greeting" {
    frame $w.$i -bd 2
    entry $w.$i.entry -relief sunken -width 40 -textvariable $i -background snow2
    label $w.$i.label
    pack $w.$i.entry -side right
    pack $w.$i.label -side left
}
$w.tkvoicedir.label config -text "TkVoice Home Dir. :"
$w.voicedir.label config -text "Voice Spool Dir.  :"
$w.voicein.label config -text "Incoming Dir.     :"
$w.voiceout.label config -text "Messages Dir.     :"
$w.greeting.label config -text "Greeting RMD file :"
pack $w.msg1 $w.tkvoicedir $w.msg2 $w.voicedir $w.msg3 $w.voicein $w.msg4 $w.voiceout $w.msg5 $w.greeting -side top -fill x
focus $w.tkvoicedir.entry
bind $w.tkvoicedir.entry <Return> {focus $w.voicedir.entry}
bind $w.voicedir.entry <Return> {focus $w.voicein.entry}
bind $w.voicein.entry <Return> {focus $w.voiceout.entry}
bind $w.voiceout.entry <Return> {focus $w.greeting.entry}
bind $w.greeting.entry <Return> {focus $w.tkvoicedir.entry}

==> tkvoice-1.5.tar.gz: tkvoice-1.5/TCL/tkvsetupvoice.tcl <==
# tkvsetupvoice.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvpaths
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Setup VOICE"
wm iconname $w "tkVoice Setup VOICE"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global drawvoice
set bgcolor "#eeeeee"

################################

proc restartmsg {} {
global w
tk_messageBox -icon warning -type ok \
	-title "VOICE SUPPORT WARNING" -parent $w\
	-message "\"RESTART\" of tkVoice is required for VOICE support changes to take affect.\n\nRemember to \"SAVE\"."
}

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicevoice}
image create photo tkvoicevoice -file [file join $tkvoicedir/image/tkvoicevoice.gif]

label $w.gif.tkvoicevoice -image tkvoicevoice -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicevoice -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right


#########################

frame $w.top
pack $w.top -side top -expand yes -pady .5c -padx .5c
checkbutton $w.top.drawvoice -text "VOICE support ON/OFF" -variable drawvoice \
            -relief flat -onvalue "1" -offvalue "0" -command "restartmsg"
pack $w.top.drawvoice -side top -pady .1c -anchor w
# n,ne, e, se, s, sw, w, nw, center
label $w.msg1 -font $font -width 40 -anchor w -justify left -text "\t\t\"TkVoice\" Installation Directory ?\n\t\tDefault is: \"/usr/local/tkvoice\""
label $w.msg2 -font $font -width 40 -anchor w -justify left -text "\n\t\t\"vgetty\" voice.conf directory ?\n\t\tDefault is: \"/usr/local/etc/mgetty+sendfax\"\t"

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savevoice; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -pady .3c -side left -expand 1

foreach i "tkvoicedir voicecfg" {
    frame $w.$i -bd 2
    entry $w.$i.entry -relief sunken -width 40 -textvariable $i -background $bgcolor
    label $w.$i.label
    pack $w.$i.entry -side right
    pack $w.$i.label -side left
}
$w.tkvoicedir.label config -text "TkVoice Home Dir. :"
$w.voicecfg.label config -text "\"voice.conf\" Dir.  :"
pack $w.msg1 $w.tkvoicedir $w.msg2 $w.voicecfg -side top -fill x
focus $w.tkvoicedir.entry
bind $w.tkvoicedir.entry <Return> {focus $w.voicecfg.entry}
bind $w.voicecfg.entry <Return> {focus $w.tkvoicedir.entry}
